#!/bin/bash
#
# Welcome to the OurDelta bakery (CentOS edition)
# Arjen Lentz <arjen@openquery.com>


# Exit immediately on any error
set -e

# Debug script and command lines
#set -x
if [ ! $# -eq 1 ]; then
    echo "Usage: $0 [tarball]"
    echo "    tarball: ourdelta or ourdelta-sail tarball"
    exit 1
else
    TARPATH="$(readlink -f ${1})"
	TARBALL="$(basename ${TARPATH})"
	
fi

if [ ! -f ${TARPATH} ]; then
    echo "Can't find tarball: ${1}"
    exit 1
fi

BZR_INFO_FILE="$(dirname $(readlink -f ${0}))/../.bzr-version"
if [ ! -f ${BZR_INFO_FILE} ]; then
    echo "No bzr version info. You are not running this script from a"
    echo "properly exported bakery. Please do so. I will now quit."
    exit 1
else
    source ${BZR_INFO_FILE}
fi

TARGET="$(echo ${TARBALL} | cut -d- -f 4- | cut -d. -f1)"
RPMTARGET="$(echo ${TARGET} | tr -d -)"
BASEVERSION="$(echo ${TARBALL} | cut -d- -f 2)"
PATCHLEVEL="$(echo ${TARBALL} | cut -d- -f 3)"
ELVERSION="$(cat /etc/redhat-release | sed "s/.*[Rr]elease //" | cut -d '.' -f 1)";

# gpg key foo
cp /srv/shared/rpmsign/home-dot-rpmmacros ~/.rpmmacros
cp /srv/shared/gnupg/* ~/.gnupg/

# our sources / patches / SPEC
cp -f "${TARPATH}" /usr/src/redhat/SOURCES
# no additional patches right now, we use our prepared ourdelta(-sail) source tarball
cp -f "$(dirname $(readlink -f ${0}))/mysql50-ourdelta-centos.spec" /usr/src/redhat/SPECS

# our build root - just still don't try multiple rpmbuilds at the same time
cd /usr/src/redhat

echo "Going to build mysql ${TARGET} ${BASEVERSION}.${PATCHLEVEL} buildrev ${REPO_VERSION}.el${ELVERSION}"

# add -vv for very verbose
rpmbuild -vv -ba SPECS/mysql50-ourdelta-centos.spec \
	--sign \
	--define '_with_yassl 1' \
	--define "mysqlversion ${BASEVERSION}" \
	--define "elversion ${ELVERSION}" \
	--define "patchset ${PATCHLEVEL}" \
	--define "buildrev ${REPO_VERSION}" \
	--define "${RPMTARGET} 1" \
	1>~/autobake-${TARGET}.log 2>&1

ls -R1 RPMS/* SRPMS/* | grep OurDelta

# finito
