#!/bin/bash
# 
# Welcome to the OurDelta bakery.
# 2008-11-01
# Peter Lieverdink <peter@openquery.com>
# Arjen Lentz <arjen@openquery.com>
#

# Should whine about packages this script depends on...
# they are not necessarily build-depends for upstream mysql.
# E.g: devscripts, fakeroot, bzr, readlink

# Source our shared util functions.
#
BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"
source ${BAKERY_BASE_DIR}/util/util.sh

# Exit immediately on any error
set -e

# Debug script and command lines
#set -x

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"
BUILD_BASE_DIR="$(pwd)/build-temp-$$"
DEB_POOL_BASE="/srv/shared/deb-pool"

export DEB_BUILD_OPTIONS="fulltest"

if [ ! $# -eq 1 ]; then
	echo "Usage: $0 [tarball]"
	echo "    tarball: ourdelta or ourdelta-sail tarball"
	exit 1
else
	TARBALL="$(readlink -f ${1})"
fi

if [ ! -f ${TARBALL} ]; then
	echo "Can't find tarball: ${1}"
	exit 1
fi

# Determine source name
#
SOURCE_DIR=$(basename ${TARBALL} .tar.gz)

# Find out the bakery version, so we can adjust the changelog file later.
#
pushd ${BAKERY_BASE_DIR}/..
if [ ! -f .bzr-version ]; then
    echo "No bzr version info. You are not running this script from a"
    echo "properly exported bakery. Please do so. I will now quit."
    exit 1
else
    source .bzr-version
fi
popd

# Find major.minor version.
#
UPSTREAM="$(echo ${SOURCE_DIR} | cut -d- -f 2)"
MYVER="$(echo ${SOURCE_DIR} | cut -d- -f 2 | cut -d. -f1,2)"

# Whatup?
#
echo "Going to build ${SOURCE_DIR} in ${BUILD_BASE_DIR}"


# Unpack tarball in our build base dir.
#
# test -d ${BUILD_BASE_DIR} && rm -fr ${BUILD_BASE_DIR}
echo "Unpacking tarball"
mkdir ${BUILD_BASE_DIR}
pushd ${BUILD_BASE_DIR}
tar xfz ${TARBALL}

# Copy the correct debian build script and patch tree from
# the bzr co we were invoked from. This way, versions always
# match this build script.
#
pushd "${BUILD_BASE_DIR}/${SOURCE_DIR}"
rm -rf ./debian
cp -r "${BAKERY_BASE_DIR}/debian-${MYVER}" debian

# Set version info (again)
#
source .ourdelta-version

# Set symlinks for build files in the debian dir, so we avoid adding AppArmor on Debian.
DISTRO="$(lsb_release -si)"
echo "Copying distribution specific build files for ${DISTRO}"
DISTROFILES="control mysql-server-5.0.dirs mysql-server-5.0.files mysql-server-5.0.postinst mysql-server-5.0.postrm mysql-server-5.0.preinst mysql-server-5.0.README.Debian mysql-server-core-5.0.files rules"
for distrofile in ${DISTROFILES}; do
  rm -f "./debian/${distrofile}";
  if [ -e "./debian/dist/${DISTRO}/${distrofile}" ]; then
	cp -a "./debian/dist/${DISTRO}/${distrofile}" "./debian/${distrofile}"
  fi
done;

# It seems that dropbox clears the x bit on the rules file, preventing
# us from autoamgically building on the remote boxes. Put it back.
#
chmod +x ./debian/rules

# Adjust changelog, add new version.
#
# Due to versioning malarkey on Ubuntu Jaunty and higher, we may need a workaround.
echo "Checking if we need a special version prefix"
VERSIONFIX="$(${BAKERY_BASE_DIR}/util/versionfix.sh)"

echo "Incrementing changelog and starting build scripts"
CODENAME="$(lsb_release -c | cut -d: -f2 | sed 's/\s//g')"
# this sets the changelog author info so it uses the right gpg signing key later
export DEBEMAIL="autosign@ourdelta.org"
export DEBFULLNAME="OurDelta Auto Signing Key"
dch -b -D ${CODENAME} -v "${VERSIONFIX}${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}${REPO_VERSION}" "Automatic build with OurDelta patchset ${PATCHLEVEL} (including Sphinx storage engine)."

echo "Creating package version ${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}${REPO_VERSION} ... "

# Copy in up-to-date gpg keys
if [ -d /srv/shared/gnupg ]; then
  if [ ! -d ~/.gnupg.pre-ourdelta ]; then
    mv ~/.gnupg ~/.gnupg.pre-ourdelta
    mkdir ~/.gnupg
    cp /srv/shared/gnupg/* ~/.gnupg/
    chmod -R go-rwx ~/.gnupg/
  fi
fi

# Build the package.
#
fakeroot dpkg-buildpackage

# Check if the local mirror deb-pool exists and move the results there.
POOL_DIR="${DEB_POOL_BASE}/${CODENAME}/${RELEASE_NAME}{$RELEASE_EXTRA:-${RELEASE_EXTRA}}"
if [ -d "${POOL_DIR}" ]; then
    popd
    echo "Moving all built files to ${POOL_DIR}"
    mv *.{deb,dsc,changes,gz} "${POOL_DIR}"

# Cleanup
    popd
    rm -fr "${BUILD_BASE_DIR}"
else
    popd
    echo "Build complete ${BUILD_BASE_DIR}"

    popd
fi

# end of autobake script
