#! /bin/bash

# Build generic binaries.

# Abort on error
set -e

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"

TARBALL="${1}"
if [ -z "$TARBALL" ]; then
	echo 1>&2 "Usage: $0 tarball.tar.gz"
	exit 1
fi

WORKDIR="build-temp-$$"

if [ ! -f "$TARBALL" ]; then
	echo 1>&2 "Can't find tarball: $TARBALL"
	exit 1
else
	TARBALL="$(readlink -f "$TARBALL")"
fi

pushd ${BAKERY_BASE_DIR}/..
if [ ! -f .bzr-version ]; then
    echo "No bzr version info. You are not running this script from a"
    echo "properly exported bakery. Please do so. I will now quit."
    exit 1
else
    source .bzr-version
fi
popd

# Determine source name
#
SOURCE_DIR=$(basename ${TARBALL} .tar.gz)

echo "Unpacking sources..."

mkdir "$WORKDIR"
cd "$WORKDIR"
tar zxf "$TARBALL"
cd "$SOURCE_DIR"

echo "Compiling ..."

# Lets not default to make -j6, but actually check the number of cores.
AM_MAKEFLAGS="-j$(if [ -f /proc/cpuinfo ] ; then grep -c processor.* /proc/cpuinfo ; else echo 1 ; fi)"
if [ ${AM_MAKEFLAGS} = -j0 ]; then
  AM_MAKEFLAGS=-j1
fi
export AM_MAKEFLAGS

BUILD/compile-bintar > ../../build.log 2>&1

echo "Building binary distribution..."

scripts/make_binary_distribution  >> ../../build.log 2>&1

# Now rename the tarball (and content) to omit the redundant -MariaDB suffix.
ORIG_TAR=$(echo mariadb-*.tar.gz)
ORIG_DIR=$(basename ${ORIG_TAR} .tar.gz)
NEW_DIR="$(echo "${ORIG_DIR}" | sed -e 's/-MariaDB//')"
NEW_TAR="${NEW_DIR}.tar.gz"

rm -Rf $ORIG_DIR
tar zxf $ORIG_TAR
mv $ORIG_DIR "${NEW_DIR}"
tar zcf "../../${NEW_TAR}" "${NEW_DIR}/"

echo "Successfully build generic bintar package $NEW_TAR"

exit 0
