#!/bin/bash
#
# Welcome to the OurDelta bakery (CentOS edition)
# Arjen Lentz <arjen@openquery.com>


# Exit immediately on any error
set -e

# Debug script and command lines
#set -x
if [ ! $# -eq 1 ]; then
    echo "Usage: $0 [tarball]"
    echo "    tarball: ourdelta or ourdelta-sail tarball"
    exit 1
else
    TARPATH="$(readlink -f ${1})"
    TARBALL="$(basename ${TARPATH})"
fi

if [ ! -f ${TARPATH} ]; then
    echo "Can't find tarball: ${1}"
    exit 1
fi

BZR_INFO_FILE="$(dirname $(readlink -f ${0}))/../.bzr-version"
if [ ! -f ${BZR_INFO_FILE} ]; then
    echo "No bzr version info. You are not running this script from a"
    echo "properly exported bakery. Please do so. I will now quit."
    exit 1
else
    source ${BZR_INFO_FILE}
fi

PACKAGE="$(echo ${TARBALL} | cut -d- -f 1)"
TARGET="ourdelta"
#TARGET="$(echo ${TARBALL} | cut -d- -f 4- | cut -d. -f1)"
RPMTARGET="$(echo ${TARGET} | tr -d -)"
BASEVERSION="$(echo ${TARBALL%.tar.gz} | cut -d- -f 2)"
# no additional patches right now
PATCHLEVEL="0"
#PATCHLEVEL="$(echo ${TARBALL} | cut -d- -f 3)"
ELVERSION="$(cat /etc/redhat-release | sed "s/.*[Rr]elease //" | cut -d '.' -f 1)"

# find rpm to grab .so.15 (5.0 client libraries) from
# note: this is an ourdelta build env dependency
# ELVERSION= 4 or 5
# ARCH= i386 or x86_64
ARCH="$(rpmbuild --showrc | grep "^build arch" | tr -s ' ' '\t' | cut -f 4-)"
COMPAT50RPM="$(ls -1 /srv/shared/yum/CentOS/${ELVERSION}/${ARCH}/RPMS/MySQL-OurDelta-shared-5.0.*.d*-*.el${ELVERSION}.${ARCH}.rpm | tail -n 1)"
if [ ! -f ${COMPAT50RPM} ]; then
    echo "Can't find a MySQL 5.0 shared RPM for .so.15 compatibility libraries"
    exit 1
fi

if [ "$RPM_SKIP_SIGN" ]; then
    SIGN=""
else
    # gpg key foo
    cp /srv/shared/rpmsign/home-dot-rpmmacros ~/.rpmmacros
    cp /srv/shared/gnupg/* ~/.gnupg/
    SIGN="--sign"
fi

# our sources / patches / SPEC
cp -f "${TARPATH}" "${COMPAT50RPM}" /usr/src/redhat/SOURCES
# no additional patches right now, we use our prepared ourdelta(-sail) source tarball
cp -f "$(dirname $(readlink -f ${0}))/mysql51-ourdelta-centos.spec" /usr/src/redhat/SPECS

# our build root - just still don't try multiple rpmbuilds at the same time
cd /usr/src/redhat

echo "Going to build ${PACKAGE}-${BASEVERSION}${PATCHLEVEL:+.${PATCHLEVEL}}-${REPO_VERSION}.el${ELVERSION} (+compat ${COMPAT50RPM})"

# add -vv for very verbose
rpmbuild -vv -ba SPECS/mysql51-ourdelta-centos.spec \
	$SIGN \
	--define "mysqlversion ${BASEVERSION}" \
	--define "elversion ${ELVERSION}" \
	--define "patchset ${PATCHLEVEL}" \
	--define "buildrev ${REPO_VERSION}" \
	--define "upstream_source ${TARBALL%.tar.gz}" \
	--define "${RPMTARGET} 1" \
	--define "compat50rpm ${COMPAT50RPM}" \
	1>~/autobake-${TARGET}.log 2>&1

ls -R1 RPMS/* SRPMS/* | grep MariaDB

# finito
