#!/bin/bash
#
# Welcome to the OurDelta build env creator.
# 2008-11-05
# Peter Lieverdink <peter@openquery.com>
# Arjen Lentz <arjen@openquery.com>
#
# This script does a bzr export of the build dirs and creates a source tarball.

# Exit immediately on any error
set -e

#
#
BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"

# Source our shared util functions.
#
. ${BAKERY_BASE_DIR}/util/util.sh

# Make sure bzr is installed.
#
testbin "bzr" || exit 1

# Debug script and command lines
#set -x

# Where are we exporting to?
EXPORT_DIR="$(pwd)"

# Jump to the bzr tree.
#
pushd "${BAKERY_BASE_DIR}"
cd ..

# Find the current repo version.
#
REPO_VERSION="$(bzr version-info | awk -F': ' '/^revno/ { print $2}')"

# This is where we'll be exporting to.
#
PREHEAT_EXPORT_DIR="${EXPORT_DIR}/bakery-${REPO_VERSION}"

# If target exists, delete it.
#
if [ -d "${PREHEAT_EXPORT_DIR}" ]; then
	/bin/rm -rf "${PREHEAT_EXPORT_DIR}"
fi

# Export, then add version info for use in other scripts.
#
bzr export "${PREHEAT_EXPORT_DIR}"
echo "REPO_VERSION=${REPO_VERSION}" > "${PREHEAT_EXPORT_DIR}/.bzr-version"

echo
echo "Created build environment in ${PREHEAT_EXPORT_DIR}"
echo "You may do with it as you choose."

# If no param, we don't know what versuion we're working on, so just exit now.
#
if [ ! $# -eq 1 ]; then
	exit 0
fi

# Back to where we were, plz kthxbai.
#
popd

# Otherwise, we DO want to run tarbake.
#
${PREHEAT_EXPORT_DIR}/bakery/tarbake.sh "${1}"
