#!/bin/bash
# 
# Welcome to the OurDelta tarball bakery.
# 2008-11-01
# Peter Lieverdink <peter@openquery.com>
# Arjen Lentz <arjen@openquery.com>
#
UPSTREAM_DIR=/srv/shared/mysql

# Exit immediately on any error
set -e

# Source our shared util functions.
#
BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"
source ${BAKERY_BASE_DIR}/util/util.sh

# Make sure source dir exists.
#
testdir ${UPSTREAM_DIR} || exit 1

# Check we have some required tools installed.
#
testbin "quilt" || exit 1

# Debug script and command lines
#set -x

BAKERY_BASE_DIR="$(dirname $(readlink -f ${0}))"
BUILD_BASE_DIR="$(pwd)/build-temp-$$"

if [ ! $# -eq 1 ]; then
	echo "Usage: $0 [upstreamversion]"
	exit 1
else
	UPSTREAM="${1}"
fi

echo "Going to build tarballs in ${BUILD_BASE_DIR}"

# Check for tarball. If not present, fetch.
#
if [ ! -f "${UPSTREAM_DIR}/mysql-${UPSTREAM}.tar.gz" ]; then
	echo "no tarball, go fish"
	# yada yada wget...
	exit 1
else
	TARBALL="${UPSTREAM_DIR}/mysql-${UPSTREAM}.tar.gz"
fi

# Find major.minor version.
#
MAJOR="$(echo ${UPSTREAM} | awk -F. '{print $1}' )"
MINOR="$(echo ${UPSTREAM} | awk -F. '{print $2}' )"

# Our Quilt patch file
#
PATCHFILE="${BAKERY_BASE_DIR}/../mysql/${MAJOR}.${MINOR}/patches-build-ourdelta"
# Which line# in the patch file delineates OurDelta baseline and -Sail
# (find line of the sail comment, chop off everything after line number)
SAILLINE=`grep -n '# OurDelta Sail' ${PATCHFILE} | sed 's/\([0-9]*\).*/\1/'`
# Work out name of last baseline patch
# (output all lines upto sail delineator, remove all comment lines, keep last real line)
LASTDELTAPATCH=`head -n ${SAILLINE} ${PATCHFILE} | grep -v '^#' | tail -n 1`

# we call this function once for regular and once for -sail
# we use to just extend regular with sail,
# but since 5.0.77-d8 that's apparently not clean enough.
# call with ${LASTDELTAPATCH} (regular) or -a (sail)
function patchntar {
	# Unpack tarball in our build base dir.
	#
	test -d ${BUILD_BASE_DIR} && rm -fr ${BUILD_BASE_DIR}
	echo "Unpacking tarball ${TARBALL}"
	mkdir ${BUILD_BASE_DIR}
	pushd ${BUILD_BASE_DIR}
	tar xfz ${TARBALL}

	# Apply the quilt patches, this means we will build a source package with
	# ourdelta patches built-in, but debian/ubuntu ones kept separate.
	#
	echo "Applying quilt patches"
	cd ${BUILD_BASE_DIR}/mysql-${UPSTREAM}
	export QUILT_PATCHES="${BAKERY_BASE_DIR}/../mysql/${MAJOR}.${MINOR}"
	quilt setup "${PATCHFILE}"

	# Apply the patches
	#
	quilt push $1

	# We need autorun (automake) to sort out the configure for some plugins
	#
	./BUILD/autorun.sh

	# Source the file that now exists, so we can use its version info for the tarball.
	#
	. .ourdelta-version

	# Up a dir, rename us and then package up.
	#
	cd ..
	mv "mysql-${UPSTREAM}" "mysql-${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}"
	# Tar it up, but leave the quilt directory out of it
	#
	tar cz --exclude="*\.pc*" --exclude="*series*" -f "mysql-${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}.tar.gz" "mysql-${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}"
	echo "Created mysql-${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}.tar.gz"

	# Move out the delta tarball.
	#
	popd
	mv -f "${BUILD_BASE_DIR}/mysql-${UPSTREAM}-d${PATCHLEVEL}-${RELEASE_NAME}${RELEASE_EXTRA:+-${RELEASE_EXTRA}}.tar.gz" .

	# Cleanup
	rm -fr "${BUILD_BASE_DIR}"
}
# end of function patchntar

echo "Working on ourdelta source tarball"
patchntar ${LASTDELTAPATCH}
echo "Working on ourdelta-sail source tarball"
patchntar -a

# Thank you, and good night.
